"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _bind = _interopRequireDefault(require("classnames/bind"));
var _terraThemeContext = _interopRequireDefault(require("terra-theme-context"));
var _terraImage = _interopRequireDefault(require("terra-image"));
var _ProfileImageModule = _interopRequireDefault(require("./ProfileImage.module.scss"));
var _excluded = ["src", "alt", "fit", "height", "width", "variant", "onLoad", "onError"];
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
var cx = _bind.default.bind(_ProfileImageModule.default);

/* eslint react/no-unused-prop-types: [0] */
var propTypes = {
  /**
   * The source for the image which will be displayed.
   */
  src: _propTypes.default.string,
  /**
   * The text content that specifies an alternative text for an image.
   *
   * ![IMPORTANT](https://badgen.net/badge/UX/Accessibility/blue) For accessibility best practices, the `alt` description must be provided in most situations.
   */
  alt: _propTypes.default.string,
  /**
  * Sets the `object-fit` style of the image from the following values: `cover`, `contain`, `scale-down`, `none`.
  *
  * ![IMPORTANT](https://badgen.net/badge/UX/Design-Standards/blue) Anywhere the terra-profile-image is used to show images of People, _only_ `cover` and `contain` are acceptable.
  */
  fit: _propTypes.default.oneOf(['cover', 'scale-down', 'contain', 'none']),
  /**
   * Sets the height of the image. Note: always define the width and height of the image as number value in pixels, e.g. `height="75"` for "75px".
   */
  height: _propTypes.default.string,
  /**
   * Sets the width of the image. Note: always define the width and height of the image as number value in pixels, e.g. `width="75"` for "75px".
   */
  width: _propTypes.default.string,
  /**
   * Sets the style of the image from the following values; `default`, `rounded`, `circle`, `thumbnail`.
   */
  variant: _propTypes.default.oneOf(['default', 'rounded', 'circle', 'thumbnail']),
  /**
   * Function to be executed when the profile image load is successful.
   */
  onLoad: _propTypes.default.func,
  /**
   * Function to be executed when the profile image load errors.
   */
  onError: _propTypes.default.func
};
var defaultProps = {
  fit: 'cover',
  height: '75',
  width: '75',
  variant: 'default'
};
var isOnlyNumbers = function isOnlyNumbers(toTest) {
  return !/\D/.test(toTest);
};
var ProfileImage = function ProfileImage(props) {
  var src = props.src,
    alt = props.alt,
    fit = props.fit,
    height = props.height,
    width = props.width,
    variant = props.variant,
    onLoad = props.onLoad,
    onError = props.onError,
    customProps = _objectWithoutProperties(props, _excluded);
  var theme = _react.default.useContext(_terraThemeContext.default);

  // Terra-Image uses a height and width attribute using only numbers, the placeholder span needs css in 'px'
  var placeholderHeight = isOnlyNumbers(height) ? "".concat(height, "px") : height;
  var placeholderWidth = isOnlyNumbers(width) ? "".concat(width, "px") : width;
  var placeholderSize = {
    height: placeholderHeight,
    width: placeholderWidth
  };
  var placeholderClassNames = (0, _classnames.default)(cx(['profile-image', 'placeholder', fit, variant, theme.className]), customProps.className);

  /* eslint-disable react/forbid-dom-props */
  var profileImagePlaceholder = /*#__PURE__*/_react.default.createElement("span", _extends({}, customProps, {
    role: alt ? 'img' : 'presentation',
    "aria-label": alt,
    style: placeholderSize,
    className: placeholderClassNames
  }));
  /* eslint-enable react/forbid-dom-props */

  if (src) {
    var profileImageClassNames = (0, _classnames.default)(cx(['profile-image', theme.className]), customProps.className);
    return /*#__PURE__*/_react.default.createElement(_terraImage.default, _extends({}, customProps, {
      src: src,
      alt: alt,
      role: alt ? 'img' : 'presentation',
      height: height,
      width: width,
      fit: fit,
      variant: variant,
      placeholder: profileImagePlaceholder,
      onLoad: onLoad,
      onError: onError,
      className: profileImageClassNames
    }));
  }
  return profileImagePlaceholder;
};
ProfileImage.propTypes = propTypes;
ProfileImage.defaultProps = defaultProps;
var _default = exports.default = ProfileImage;